@@ -5,12 +5,13 @@
 #' @param isoTime character; A string time representation.
 #' @param units character; Units to return. Default:
 #' "seconds since 1970-01-01T00:00:00Z"
-#' @param url Base URL of the ERDDAP server
+#' @param url Base URL of the ERDDAP server. See [eurl()] for 
+#' more information
 #' @param method (character) One of local or web. Local simply uses
-#' \code{as.POSIXct}, while web method uses the ERDDAP time conversion service
-#' \code{/erddap/convert/time.txt}
-#' @param ... Curl args passed on to \code{\link[httr]{GET}}
-#' @details When \code{method = "web"} time zone is GMT/UTC
+#' [as.POSIXct()], while web method uses the ERDDAP time conversion service
+#' `/erddap/convert/time.txt`
+#' @param ... Curl options passed on to [crul::HttpClient]
+#' @details When `method = "web"` time zone is GMT/UTC
 #' @examples  \dontrun{
 #' # local conversions
 #' convert_time(n = 473472000)
@@ -22,8 +23,7 @@
 #' }
 
 convert_time <- function(n = NULL, isoTime = NULL,
-  units = "seconds since 1970-01-01T00:00:00Z",
-  url = "http://coastwatch.pfeg.noaa.gov",
+  units = "seconds since 1970-01-01T00:00:00Z", url = eurl(),
   method = "local", ...) {
 
   if (!is.null(n)) stopifnot(is.numeric(n))
@@ -35,15 +35,16 @@ convert_time <- function(n = NULL, isoTime = NULL,
            format = "%Y-%m-%dT%H:%M:%SZ", tz = "UTC")
   } else {
     args <- rc(list(n = n, isoTime = isoTime, units = units))
-    res <- GET(paste0(pu(url), '/erddap/convert/time.txt'), query = args, ...)
-    stop_for_status(res)
-    content(res, "text")
+    cli <- crul::HttpClient$new(url = file.path(pu(url), 'convert/time.txt'), 
+      opts = list(...))
+    res <- cli$get(query = args)
+    res$raise_for_status()
+    res$parse("UTF-8")
   }
 }
 
 depsub <- function(x) {
   deparse(substitute(x, env = parent.env()))
-  # deparse(substitute(x, env = parent.frame()))
 }
 
 check1notboth <- function(x, y) {
