@@ -2,12 +2,13 @@ context("info")
 
 test_that("info returns the correct", {
   skip_on_cran()
-
-  a <- info('noaa_esrl_027d_0fb5_5d38')
-  #b <- info('noaa_gfdl_31d5_ca95_1287')
-  d <- info('noaa_esrl_5ee0_7c46_db68')
-  e <- info('noaa_esrl_c028_2e8a_9caf')
-  f <- info('nodcWoa09mon5t')
+   vcr::use_cassette("info", {
+    a <- info('erdRWtanm1day')
+    #b <- info('noaa_gfdl_31d5_ca95_1287')
+    d <- info('erdMBchlamday_LonPM180')
+    e <- info('erdMBchla1day')
+    f <- info('nodcWoa09mon5t')
+  })
 
   # class
   expect_is(a, "info")
@@ -19,10 +20,10 @@ test_that("info returns the correct", {
   expect_is(a$variables, "data.frame")
   expect_is(a$alldata, "list")
   expect_is(a$alldata$NC_GLOBAL, "data.frame")
-  expect_is(a$alldata$air, "data.frame")
+  expect_is(a$alldata$sstAnomaly, "data.frame")
 
   #expect_is(b$alldata$clivi, "data.frame")
-  expect_is(d$alldata$air, "data.frame")
+  expect_is(d$alldata$chlorophyll, "data.frame")
   expect_is(e$alldata$time, "data.frame")
   expect_is(f$alldata$depth, "data.frame")
 
@@ -33,8 +34,9 @@ test_that("info returns the correct", {
 
 test_that("info works with different ERDDAP servers", {
   skip_on_cran()
-
-  h <- info("erdMH1kd4908day", url = "https://bluehub.jrc.ec.europa.eu/erddap/")
+  vcr::use_cassette("info_diff_servers", {
+    h <- info("IMI_CONN_2D", url = "http://erddap.marine.ie/erddap/")
+  })
 
   expect_is(h, "info")
   expect_is(h$variables, "data.frame")
@@ -45,5 +47,5 @@ test_that("info fails well", {
   skip_on_cran()
 
   expect_error(info(), "is missing, with no default")
-  expect_error(info("stuff"), "HTTP Status 404 - Resource not found")
+  expect_error(info("stuff"), "Not Found")
 })
